@@ -1,7 +1,5 @@
 package Benchmark::Perl::Formance::Plugin::DPath;
-BEGIN {
-  $Benchmark::Perl::Formance::Plugin::DPath::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: benchmark plugin - DPath - stress lookup, traversing and copying data structures
 
 use strict;
@@ -503,7 +501,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
