@@ -1,7 +1,5 @@
 package Benchmark::Perl::Formance::Plugin::Shootout;
-BEGIN {
-  $Benchmark::Perl::Formance::Plugin::Shootout::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: benchmark plugin - Shootout - Benchmark::Perl::Formance plugin covering Shootout code
 
 use strict;
@@ -133,7 +131,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
