@@ -1,7 +1,5 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::knucleotide;
-BEGIN {
-  $Benchmark::Perl::Formance::Plugin::Shootout::knucleotide::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: benchmark - Hashtable update and k-nucleotide strings
 
 # COMMAND LINE:
@@ -152,7 +150,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
